durationtools.assignable_rational_to_lilypond_duration_string
=============================================================

.. autofunction:: abjad.tools.durationtools.assignable_rational_to_lilypond_duration_string.assignable_rational_to_lilypond_duration_string
